% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code has been written by Adelie Antoine, using functions from
% animaltags (M. Johnson, Animal Tag Tools Wiki (2017).
% URL https:// animaltags.org/), and following P. Goulet's work.
%
% It is designed to extract prey characteristics according to the period of
% the day.
%
% Last modification : February 2023
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



clear all
close all

%% Load the dataset containing the results of the echograms visual analysis

% The structure must contain (with array names in quotes):
% - individual identification, "indiv"
% - yes/no answers for the presence of a signal corresponding to the bottom
% of the ocean on the echogram, "presence_bottom"
% - yes/no answers for the presence of a signal corresponding to a prey on 
% the echogram, "presence_prey"
% - yes/no answers for the presence of individual prey (as opposed to
% several preys), "indiv_prey"
% - yes/no answers for the presence of a signal corresponding to a reacting
% prey, "prey_reaction"
% - type of reaction, "reaction_type"
% - time at which the reaction is first spotted, "reaction_time"
% - distance at which the reaction is first spotted, "reaction_distance"
% - prey acoustic size, "prey_size"
% - index of the PrCA corresponding to the echogram that was analyzed,
% "index_jerk"

% The structure is hereafter called "sonar_game"

% Prey capture attemptes are hereafter noted (PCA).

% We suppose that the studied individual is identified as "314a"

%% load all necessary data
angle_sun = load(['.../lw19_314a_sunangle.mat']); % Load file with sun angle values during dives 

load('.../lw19_314a_dives.mat') % load file containing dives for the studied individual

load('.../lw19_314a_jerks_fullbandwidth.mat') % load file containing jerk data at full bandwidth

addpath(genpath('.../dtag_and_sonar_tools/'));

%% start filling file for prey characteristics tests
% get the PCA index in the sonar_game
idx_pca_14a_sonargame_file = find(sonar_game.indiv=="lw19_314a");

% get the PCA index in the original file (fullBW file, called "jerks" in
% workspace)
idx_pca_14a = sonar_game.index_jerk(idx_pca_14a_sonargame_file);

jerk_start = jerks.start_time(idx_pca_14a); % extract pca start time
jerk_end = jerks.end_time(idx_pca_14a); % extract pca end time
idx_dives = []; % initate dive index double
for ii = 1 : length(jerk_start) % for all PCA
    idx = find(dives.start <= jerk_start(ii,1) & dives.end >= jerk_end(ii,1)); % get corresponding dive index 
    idx_dives =cat(1,idx_dives,idx); % save index of all dives with PCA in a double, /!\ including repeated dives if several PCAs
end 

% add sunangle for each pca 
sunangle = [];
for ii = 1 : length(idx_dives)
    k = idx_dives(ii,1);
    angle = angle_sun.dives.sunangle(k);
    sunangle = cat(1, sunangle, angle);
end 

% add prey characteristics for each pca 
presence_bottom = sonar_game.presence_bottom(idx_pca_14a_sonargame_file); % bottom trace 
presence_prey = sonar_game.presence_prey(idx_pca_14a_sonargame_file); % prey trace
indiv_prey = sonar_game.indiv_prey(idx_pca_14a_sonargame_file); % single or schooling prey 
prey_reaction = sonar_game.prey_reaction(idx_pca_14a_sonargame_file); % reaction trace 
reaction_type = sonar_game.reaction_type(idx_pca_14a_sonargame_file); % reaction type
reaction_time = sonar_game.reaction_time(idx_pca_14a_sonargame_file); % reaction time
reaction_distance = sonar_game.reaction_distance(idx_pca_14a_sonargame_file); % reaction distance
prey_size = sonar_game.prey_size(idx_pca_14a_sonargame_file); % prey size 

% lastly, add depth to compare potential interaction with sunangle
depth = sonar_game.depth(idx_pca_14a_sonargame_file);

% then make a single object with everything :)
sunangle_prey_char = [];
sunangle_prey_char = cat(2, idx_pca_14a, idx_dives, sunangle,depth, presence_bottom,presence_prey,prey_reaction,reaction_type,reaction_time,reaction_distance,prey_size); % fill file for analysis 

sunagle_prey_char_table = array2table(sunangle_prey_char,'variableNames',{'pcabn','divenb', ...
    'sunangle','depth','presence_bottom','presence_prey','presence_reaction','prey_type','reaction_time','reaction_distance','prey_size'})

% filename  =['.../sunangle_prey_char.csv'];
% writetable(sunagle_prey_char_table, filename);


%% %%%%%%%%%% get statistics on day/twilight dives %%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

min(angle_sun.dives.sunangle)
max(angle_sun.dives.sunangle)
nb_twilight_dives = find(angle_sun.dives.sunangle > -12 & angle_sun.dives.sunangle < 0);
nb_day_dives = find(angle_sun.dives.sunangle >= 0 & angle_sun.dives.sunangle < 45);


% get the PCA index in the sonar_game
idx_pca_14a_sonargame_file = find(sonar_game.indiv=="lw19_314a");
% get the PCA index in the original file (fullBW file, called "jerks" in
% workspace)
idx_pca_14a = sonar_game.index_jerk(idx_pca_14a_sonargame_file);
jerk_start = jerks.start_time(idx_pca_14a); % extract pca start time
jerk_end = jerks.end_time(idx_pca_14a); % extract pca end time
idx_dives = []; % initate dive index double
for ii = 1 : length(jerk_start) % for all PCA
    idx = find(dives.start <= jerk_start(ii,1) & dives.end >= jerk_end(ii,1)); % get corresponding dive index 
    idx_dives =cat(1,idx_dives,idx); % save index of all dives with PCA in a double, /!\ including repeated dives if several PCAs
end 

%------------------ look at how many dives with pca take place during the day/twilight 
dives_index = unique(idx_dives);
nb_day_pca_dives = find (angle_sun.dives.sunangle(dives_index)>= 0 & angle_sun.dives.sunangle(dives_index) < 45);
nb_twilight_pca_dives = find(angle_sun.dives.sunangle(dives_index) > -12 & angle_sun.dives.sunangle(dives_index) < 0);

%------------------- look at how many benthic dives take place during the day/twilight
idx_benthic_14a_sonargame_file = find(sonar_game.indiv=="lw19_314a" & sonar_game.presence_bottom == 1);
% get the PCA index in the original file (fullBW file, called "jerks" in
% workspace)
idx_benthic_14a = sonar_game.index_jerk(idx_benthic_14a_sonargame_file);
jerk_start = jerks.start_time(idx_benthic_14a); % extract pca start time
jerk_end = jerks.end_time(idx_benthic_14a); % extract pca end time
idx_dives = []; % initate dive index double
for ii = 1 : length(jerk_start) % for all PCA
    idx = find(dives.start <= jerk_start(ii,1) & dives.end >= jerk_end(ii,1)); % get corresponding dive index 
    idx_dives =cat(1,idx_dives,idx); % save index of all dives with PCA in a double, /!\ including repeated dives if several PCAs
end 
dives_index = unique(idx_dives);
nb_day_benthic_dives = find (angle_sun.dives.sunangle(dives_index)>= 0 & angle_sun.dives.sunangle(dives_index) < 45);
nb_twilight_benthic_dives = find(angle_sun.dives.sunangle(dives_index) > -12 & angle_sun.dives.sunangle(dives_index) < 0);







